AppState enum

Represents the lifecycle state of the app.

Inheritance
Available extensions

Values

foreground → const AppState

The app is running in the foreground and visible to the user.

background → const AppState

The app is running in the background but not visible to the user.

resumed → const AppState

The app has resumed from a paused state and is active again.

paused → const AppState

The app is currently paused (partially or fully inactive).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AppState>
A constant List of the values in this enum, in order of their declaration.