dispose method
void
dispose()
Disposes the observer and removes it from the WidgetsBinding.
Implementation
void dispose() {
WidgetsBinding.instance.removeObserver(this);
}
Disposes the observer and removes it from the WidgetsBinding.
void dispose() {
WidgetsBinding.instance.removeObserver(this);
}